Module SpoePlugin_trait

Module SpoePlugin_trait 

This module is generated by the #[sabi_trait] attribute on SpoePlugin

Structs

SpoePlugin_Interface
A marker type describing the traits that are required when constructing SpoePlugin_TO,and are then implemented by it, by implementing the InterfaceType trait.
SpoePlugin_TO
The trait object for SpoePlugin.

Traits

SpoePlugin
The trait that all SPOA hub plugins must implement.

Type Aliases

SpoePlugin_Backend
An alias for the underlying implementation of SpoePlugin_TO.
SpoePlugin_CTO
A type alias for the const-constructible SpoePlugin_TO.