#[repr(transparent)]pub struct SpoePlugin_TO<'lt, _ErasedPtr>where
_ErasedPtr: __GetPointerKind,{
pub obj: SpoePlugin_Backend<'lt, _ErasedPtr>,
/* private fields */
}Expand description
The trait object for SpoePlugin.
There are extra methods on the obj field.
Fields
obj: SpoePlugin_Backend<'lt, _ErasedPtr>Implementations
Sourceimpl<'lt, _ErasedPtr> SpoePlugin_TO<'lt, _ErasedPtr>
impl<'lt, _ErasedPtr> SpoePlugin_TO<'lt, _ErasedPtr>
Sourcepub fn from_ptr<_OrigPtr, Downcasting>(
ptr: _OrigPtr,
can_it_downcast: Downcasting,
) -> Selfwhere
_OrigPtr: CanTransmuteElement<(), TransmutedPtr = _ErasedPtr>,
_OrigPtr::PtrTarget: SpoePlugin + Sized + 'lt,
SpoePlugin_Interface: GetRObjectVTable<Downcasting, _OrigPtr::PtrTarget, _ErasedPtr, _OrigPtr>,
pub fn from_ptr<_OrigPtr, Downcasting>(
ptr: _OrigPtr,
can_it_downcast: Downcasting,
) -> Selfwhere
_OrigPtr: CanTransmuteElement<(), TransmutedPtr = _ErasedPtr>,
_OrigPtr::PtrTarget: SpoePlugin + Sized + 'lt,
SpoePlugin_Interface: GetRObjectVTable<Downcasting, _OrigPtr::PtrTarget, _ErasedPtr, _OrigPtr>,
Constructs this trait object from a pointer to a type that implements SpoePlugin.
This method is automatically generated,
for more documentation you can look at
abi_stable::docs::sabi_trait_inherent
can_it_downcast describes whether the trait object can be converted back into the original type or not.
Its possible values are TD_CanDowncast and TD_Opaque.
Sourcepub fn from_sabi(obj: SpoePlugin_Backend<'lt, _ErasedPtr>) -> Self
pub fn from_sabi(obj: SpoePlugin_Backend<'lt, _ErasedPtr>) -> Self
Constructs this trait object from its underlying implementation.
This method is automatically generated,
for more documentation you can look at
abi_stable::docs::sabi_trait_inherent
Sourcepub fn sabi_reborrow<'_sub>(&'_sub self) -> SpoePlugin_TO<'lt, RRef<'_sub, ()>>
pub fn sabi_reborrow<'_sub>(&'_sub self) -> SpoePlugin_TO<'lt, RRef<'_sub, ()>>
Reborrows this trait object to a reference-based trait object.
This method is automatically generated,
for more documentation you can look at
abi_stable::docs::sabi_trait_inherent
Sourcepub fn sabi_reborrow_mut<'_sub>(
&'_sub mut self,
) -> SpoePlugin_TO<'lt, RMut<'_sub, ()>>
pub fn sabi_reborrow_mut<'_sub>( &'_sub mut self, ) -> SpoePlugin_TO<'lt, RMut<'_sub, ()>>
Reborrows this trait object to a mutable-reference-based trait object.
This method is automatically generated,
for more documentation you can look at
abi_stable::docs::sabi_trait_inherent
Sourceimpl<'lt> SpoePlugin_TO<'lt, RBox<()>>
impl<'lt> SpoePlugin_TO<'lt, RBox<()>>
Sourcepub fn from_value<_Self, Downcasting>(
ptr: _Self,
can_it_downcast: Downcasting,
) -> Selfwhere
_Self: SpoePlugin + 'lt,
SpoePlugin_Interface: GetRObjectVTable<Downcasting, _Self, RBox<()>, RBox<_Self>>,
pub fn from_value<_Self, Downcasting>(
ptr: _Self,
can_it_downcast: Downcasting,
) -> Selfwhere
_Self: SpoePlugin + 'lt,
SpoePlugin_Interface: GetRObjectVTable<Downcasting, _Self, RBox<()>, RBox<_Self>>,
Constructs this trait from a type that implements SpoePlugin.
This method is automatically generated,
for more documentation you can look at
abi_stable::docs::sabi_trait_inherent
can_it_downcast describes whether the trait object can be converted back into the original type or not.
Its possible values are TD_CanDowncast and TD_Opaque.
Sourceimpl<'lt, '_sub> SpoePlugin_TO<'lt, RRef<'_sub, ()>>
impl<'lt, '_sub> SpoePlugin_TO<'lt, RRef<'_sub, ()>>
Sourcepub const fn from_const<_Self, Downcasting>(
ptr: &'_sub _Self,
can_it_downcast: Downcasting,
) -> Selfwhere
_Self: SpoePlugin + 'lt,
SpoePlugin_Interface: GetRObjectVTable<Downcasting, _Self, RRef<'_sub, ()>, &'_sub _Self>,
pub const fn from_const<_Self, Downcasting>(
ptr: &'_sub _Self,
can_it_downcast: Downcasting,
) -> Selfwhere
_Self: SpoePlugin + 'lt,
SpoePlugin_Interface: GetRObjectVTable<Downcasting, _Self, RRef<'_sub, ()>, &'_sub _Self>,
Constructs this trait from a constant of a type that implements SpoePlugin.
This method is automatically generated,
for more documentation you can look at
abi_stable::docs::sabi_trait_inherent
You can construct the vtable_for parameter with [SpoePlugin_MV::VTABLE].
can_it_downcast describes whether the trait object can be converted back into the original type or not.
Its possible values are TD_CanDowncast and TD_Opaque.
Sourceimpl<'lt, _ErasedPtr> SpoePlugin_TO<'lt, _ErasedPtr>
impl<'lt, _ErasedPtr> SpoePlugin_TO<'lt, _ErasedPtr>
Sourcepub fn init(&mut self, param_0: &PluginContext) -> RResult<(), RBoxError>
pub fn init(&mut self, param_0: &PluginContext) -> RResult<(), RBoxError>
This is the inherent equivalent of the trait method of the same name
Sourcepub fn process(
&self,
param_0: &SpoeMessage,
) -> RResult<ProcessingResult, RBoxError>
pub fn process( &self, param_0: &SpoeMessage, ) -> RResult<ProcessingResult, RBoxError>
This is the inherent equivalent of the trait method of the same name
Sourcepub fn name<'_self>(&'_self self) -> RStr<'_self>
pub fn name<'_self>(&'_self self) -> RStr<'_self>
This is the inherent equivalent of the trait method of the same name
Sourcepub fn version<'_self>(&'_self self) -> RStr<'_self>
pub fn version<'_self>(&'_self self) -> RStr<'_self>
This is the inherent equivalent of the trait method of the same name
Sourcepub fn shutdown(&self)
pub fn shutdown(&self)
This is the inherent equivalent of the trait method of the same name
Sourcepub fn config_schema(&self) -> ROption<RString>
pub fn config_schema(&self) -> ROption<RString>
This is the inherent equivalent of the trait method of the same name
Sourcepub fn validate(&self, param_0: &PluginContext) -> RVec<Diagnostic>
pub fn validate(&self, param_0: &PluginContext) -> RVec<Diagnostic>
This is the inherent equivalent of the trait method of the same name