This module is generated by the #[sabi_trait] attribute on SpoePlugin
Structs
- Spoe
Plugin_ Interface - A marker type describing the traits that are required when constructing
SpoePlugin_TO,and are then implemented by it, by implementing theInterfaceTypetrait. - Spoe
Plugin_ TO - The trait object for SpoePlugin.
Traits
- Spoe
Plugin - The trait that all SPOA hub plugins must implement.
Type Aliases
- Spoe
Plugin_ Backend - An alias for the underlying implementation of
SpoePlugin_TO. - Spoe
Plugin_ CTO - A type alias for the const-constructible
SpoePlugin_TO.